@@ -62,8 +62,8 @@ with open(CONFIG_FILE_BACKUP, "a", encoding="utf-8") as fileObj:
 
 AGENTMAKE_ENV_PATH = os.path.join(AGENTMAKE_USER_DIR, "agentmake.env")
 if config.backend == "googleai" and not os.getenv("GOOGLEAI_API_KEY"):
-    googleai_api_key = DIALOGS.getInputDialog_sync(title="Google AI API key", text="Enter your Google AI API key:")
-    if googleai_api_key.strip():
+    googleai_api_key = DIALOGS.getInputDialog_sync(title="Google AI API Key", text="請輸入您的 Google AI API 鑰匙:")
+    if googleai_api_key and googleai_api_key.strip():
         googleai_api_key = googleai_api_key.strip()
         agentmake_env_content = readTextFile(AGENTMAKE_ENV_PATH)
         if os.path.isfile(AGENTMAKE_ENV_PATH) and "\nGOOGLEAI_API_KEY=" in agentmake_env_content:
